@@ -20,26 +20,30 @@ class MinitestTest(CliTestCase):
         self.assertEqual(result.exit_code, 0)
 
         payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[0].request.body)).decode())
+            b''.join(responses.calls[1].request.body)).decode())
 
         expected = self.load_json_from_file(self.result_file_path)
         self.assert_json_orderless_equal(expected, payload)
 
     @responses.activate
     def test_record_test_minitest_chunked(self):
-        result = self.cli('record', 'tests',  '--session', self.session, '--post-chunk', 5, 'minitest', str(self.test_files_dir) + "/")
+        result = self.cli('record', 'tests',  '--session', self.session,
+                          '--post-chunk', 5, 'minitest', str(self.test_files_dir) + "/")
         self.assertEqual(result.exit_code, 0)
 
         payload1 = json.loads(gzip.decompress(
-            b''.join(responses.calls[0].request.body)).decode())
-        expected1 = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result_chunk1.json'))
+            b''.join(responses.calls[1].request.body)).decode())
+        expected1 = self.load_json_from_file(
+            self.test_files_dir.joinpath('record_test_result_chunk1.json'))
 
         payload2 = json.loads(gzip.decompress(
-            b''.join(responses.calls[1].request.body)).decode())
-        expected2 = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result_chunk2.json'))
+            b''.join(responses.calls[2].request.body)).decode())
+        expected2 = self.load_json_from_file(
+            self.test_files_dir.joinpath('record_test_result_chunk2.json'))
 
         # concat 1st and 2nd request for unstable order
-        self.assert_json_orderless_equal(expected1['events'] + expected2['events'], payload1['events'] + payload2['events'])
+        self.assert_json_orderless_equal(
+            expected1['events'] + expected2['events'], payload1['events'] + payload2['events'])
 
     @responses.activate
     def test_subset(self):
